import java.io.File;
import java.lang.ProcessBuilder.Redirect;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

/*
 * @test
 * @bug 8072611
 * @summary ProcessBuilder Redirect to file appending on Windows should work with long file names
 * @author Thomas Stuefe
 */
public class RedirectWithLongFilename {

  public static void main(String[] args) throws Exception {

    // windows only
    if (Basic.Unix.is()) {
      return;
    }

    // Redirect ProcessBuilder output to a file whose pathlen is > 255.
    Path tmpDir = Paths.get(System.getProperty("java.io.tmpdir"));
    File dir2 = null;
    File longFileName = null;

    try {
      dir2 = Files.createTempDirectory(tmpDir, "RedirectWithLongFilename").toFile();
      dir2.mkdirs();
      longFileName = new File(
          dir2, "0123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789"
              + "0123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789"
              + "012345678901234567890123456789012345678900123456789");

      ProcessBuilder pb = new ProcessBuilder("hostname.exe");
      pb.redirectOutput(Redirect.appendTo(longFileName));
      Process p = pb.start();
      p.waitFor();

      if (longFileName.exists()) {
        System.out.println("OK");
      } else {
        throw new RuntimeException("Test failed.");
      }

    } finally {
      longFileName.delete();
      dir2.delete();
    }

  }

}
